import click

from .loader import load_default, load_file


@click.command()
@click.version_option()
@click.argument('files', nargs=-1, type=click.Path(exists=True))
def cli(files):
    env_vars = {}

    if not len(files):
        env_vars.update(load_default())
    else:
        for fname in files:
            env_vars.update(load_file(fname))

    if env_vars:
        click.echo(' '.join([
            '{0}={1}'.format(k, v) for k, v in env_vars.items()
        ]))



from print_env.exts import is_yaml, is_json


def test_is_yaml():
    cases = {
        '.yml': True,
        '.yaml': True,
        '.json': False,
        '.js': False,
        '.env': False
    }
    for k, v in cases.items():
        assert is_yaml(k) is v


def test_is_json():
    cases = {
        '.yml': False,
        '.yaml': False,
        '.json': True,
        '.js': True,
        '.env': False
    }
    for k, v in cases.items():
        assert is_json(k) is v



import os
import codecs

# dotenv loader
from dotenv import dotenv_values
# yaml loader
import yaml
# json loader
try:
    import simplejson as json
except ImportError:
    import json

from .exts import EXTS, is_yaml, is_json


def load_default():
    for fname in ['.env'] + ['env{}'.format(ext) for ext in EXTS]:
        env_file = os.path.join(os.getcwd(), fname)

        if os.path.isfile(env_file):
            return load_file(env_file)
    else:
        return {}


def load_file(fname):
    try:
        _, ext = os.path.splitext(fname)

        if not is_yaml(ext) and not is_json(ext):
            return dotenv_values(fname)

        with codecs.open(fname) as f:
            if is_yaml(ext):
                return yaml.load(f)
            elif is_json(ext):
                return json.load(f)

        return {}
    except Exception:
        return {}



import os
import shutil
import json

from print_env.loader import load_default, load_file

# patch to make FileNotFoundError "work" on Python 2.7
try:
    FileNotFoundError
except NameError:
    FileNotFoundError = IOError


FILES = ['.env', 'env.yml', 'env.json']
TEMP_PRE = 'test_'
CWD = os.getcwd()


# move default files temporarily for testing no file case
def _move(back=False):
    for f in FILES:
        env = os.path.join(CWD, f)
        temp = os.path.join(CWD, '{0}{1}'.format(TEMP_PRE, f))
        try:
            if back:
                shutil.move(temp, env)
            else:
                shutil.move(env, temp)
        except FileNotFoundError:
            pass


def test_default_nofile():
    _move()
    assert load_default() == {}
    _move(back=True)


def test_default_dotenv():
    _move()
    env_file = os.path.join(CWD, '.env')
    key = 'TEST_LOAD'
    val = 'dotenv'
    with open(env_file, 'w') as f:
        f.write('{0}={1}\n'.format(key, val))
    assert load_default() == {key: val}
    os.remove(env_file)
    _move(back=True)


def test_default_yaml():
    _move()
    for ef in ('env.yml', 'env.yaml'):
        env_file = os.path.join(CWD, ef)
        key = 'TEST_LOAD'
        val = 'yaml'
        with open(env_file, 'w') as f:
            f.write('{0}: {1}\n'.format(key, val))
        assert load_default() == {key: val}
        os.remove(env_file)
    _move(back=True)


def test_default_json():
    _move()
    for ef in ('env.js', 'env.json'):
        env_file = os.path.join(CWD, ef)
        key = 'TEST_LOAD'
        val = 'json'
        with open(env_file, 'w') as f:
            json.dump({key: val}, f)
        assert load_default() == {key: val}
        os.remove(env_file)
    _move(back=True)


def test_file_dotenv():
    _move()
    env_file = os.path.join(CWD, 'test.env')
    key = 'TEST_LOAD'
    val = 'dotenv'
    with open(env_file, 'w') as f:
        f.write('{0}={1}\n'.format(key, val))
    assert load_file(env_file) == {key: val}
    os.remove(env_file)
    _move(back=True)


def test_file_yaml():
    _move()
    for ef in ('test-env.yml', 'test-env.yaml'):
        env_file = os.path.join(CWD, ef)
        key = 'TEST_LOAD'
        val = 'yaml'
        with open(env_file, 'w') as f:
            f.write('{0}: {1}\n'.format(key, val))
        assert load_file(env_file) == {key: val}
        os.remove(env_file)
    _move(back=True)


def test_file_json():
    _move()
    for ef in ('test-env.js', 'test-env.json'):
        env_file = os.path.join(CWD, ef)
        key = 'TEST_LOAD'
        val = 'json'
        with open(env_file, 'w') as f:
            json.dump({key: val}, f)
        assert load_file(env_file) == {key: val}
        os.remove(env_file)
    _move(back=True)
